@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: error-viewer.c,v 1.13 2004/04/25 05:19:49 adamh Exp $
+ *  $Id: error-viewer.c,v 1.13.2.1 2004/09/26 16:22:39 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -64,6 +64,12 @@ enum
 	N_COLUMNS
 };
 
+/* glade callbacks */
+void error_viewer_clear_cb (GtkWidget *button,
+			    ErrorViewer *dialog);
+void error_viewer_close_cb (GtkWidget *button,
+			    ErrorViewer *dialog);
+
 static void error_viewer_class_init	(ErrorViewerClass *klass);
 static void error_viewer_init		(ErrorViewer *dialog);
 static void error_viewer_finalize	(GObject *object);
@@ -197,7 +203,6 @@ build_ui (ErrorViewer *dialog)
 	GdkPixbuf *icon;
 	GtkListStore *store;
 	GtkTreeView *treeview;
-	GtkTreeViewColumn *col;
 	GtkCellRenderer *renderer;
 	ErrorViewerPrivate *priv = dialog->priv;
 
@@ -269,7 +274,7 @@ error_viewer_init (ErrorViewer *dialog)
 static void
 error_viewer_finalize (GObject *object)
 {
-	ErrorViewer *dialog = ERROR_VIEWER (object);
+//	ErrorViewer *dialog = ERROR_VIEWER (object);
 
 	/* FIXME: Free TreeView stuff? */
 
