@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-gestures-extension.c,v 1.9 2004/03/23 21:34:55 chpe Exp $
+ *  $Id: ephy-gestures-extension.c,v 1.10.2.1 2004/09/26 16:22:39 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -41,6 +41,8 @@
 #include <gmodule.h>
 #include <libxml/tree.h>
 
+#include <string.h>
+
 #define EPHY_GESTURES_EXTENSION_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_GESTURES_EXTENSION, EphyGesturesExtensionPrivate))
 
 struct EphyGesturesExtensionPrivate
@@ -157,7 +159,7 @@ load_gestures (EphyGesturesExtension *extension,
 {
 	xmlDocPtr doc;
 	xmlNodePtr root, child;
-	xmlChar *tmp;
+	xmlChar *tmp = NULL;
 
 	if (g_file_test (filename, G_FILE_TEST_EXISTS) == FALSE)
 	{
@@ -282,8 +284,7 @@ gesture_performed_cb (EphyGesture *gesture,
 	else
 	{
 		GtkUIManager *manager;
-		GtkAction *action = NULL;
-		GList *action_groups, *l;
+		GtkAction *action;
 		
 		manager = GTK_UI_MANAGER (window->ui_merge);
 		
@@ -299,12 +300,11 @@ gesture_performed_cb (EphyGesture *gesture,
 	}
 }
 
-static gint
+static gboolean
 dom_mouse_down_cb (EphyEmbed *embed,
 		   EphyEmbedEvent *event,
 		   EphyGesturesExtension *extension)
 {
-	EphyTab *tab;
         EmbedEventContext context;
 	EphyEmbedEventType type;
 	gint handled = FALSE;
@@ -318,13 +318,12 @@ dom_mouse_down_cb (EphyEmbed *embed,
 		EphyGesture *gesture;
 		GtkWidget *toplevel;
 		EphyTab *tab;
-		guint x, y;
 
 		tab = ephy_tab_for_embed (embed);
-		g_return_if_fail (EPHY_IS_TAB (tab));
+		g_return_val_if_fail (EPHY_IS_TAB (tab), handled);
 
 		toplevel = gtk_widget_get_toplevel (GTK_WIDGET (tab));
-		g_return_if_fail (toplevel != NULL);
+		g_return_val_if_fail (toplevel != NULL, handled);
 
 		gesture = ephy_gesture_new (toplevel, event);
 
@@ -377,6 +376,17 @@ impl_attach_window (EphyExtension *extension,
 		    EphyWindow *window)
 {
 	GtkWidget *notebook;
+	GList *tabs, *l;
+
+	tabs = ephy_window_get_tabs (window);
+
+	for (l = tabs; l != NULL; l = g_list_next (l))
+	{
+		tab_added_cb (NULL, l->data,
+			      (EphyGesturesExtension *) extension);
+	}
+
+	g_list_free (tabs);
 
 	notebook = ephy_window_get_notebook (window);
 
@@ -391,6 +401,7 @@ impl_detach_window (EphyExtension *extension,
 		    EphyWindow *window)
 {
 	GtkWidget *notebook;
+	GList *tabs, *l;
 
 	notebook = ephy_window_get_notebook (window);
 
@@ -398,6 +409,16 @@ impl_detach_window (EphyExtension *extension,
 		(notebook, G_CALLBACK (tab_added_cb), extension);
 	g_signal_handlers_disconnect_by_func
 		(notebook, G_CALLBACK (tab_removed_cb), extension);
+
+	tabs = ephy_window_get_tabs (window);
+
+	for (l = tabs; l != NULL; l = g_list_next (l))
+	{
+		tab_removed_cb (NULL, l->data,
+				(EphyGesturesExtension *) extension);
+	}
+
+	g_list_free (tabs);
 }
 
 static void
