@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-tab-move-menu.c,v 1.7 2004/09/07 04:17:48 adamh Exp $
+ *  $Id: ephy-tab-move-menu.c,v 1.7.2.1 2004/09/26 16:22:40 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -109,8 +109,8 @@ find_action_group (GtkUIManager *manager)
 
 	list = gtk_ui_manager_get_action_groups (manager);
 	element = g_list_find_custom (list, "WindowActions", (GCompareFunc) find_name);
-	g_return_if_fail (element != NULL);
-	g_return_if_fail (element->data != NULL);
+	g_return_val_if_fail (element != NULL, NULL);
+	g_return_val_if_fail (element->data != NULL, NULL);
 
 	return GTK_ACTION_GROUP (element->data);
 }
@@ -212,7 +212,7 @@ update_tab_move_menu_cb (GtkAction *dummy,
 	EphyTabMoveMenuPrivate *p = menu->priv;
 	EphySession *session;
 	GtkAction *action;
-	GList *windows, *l;
+	GList *windows;
 
 	LOG ("update_tab_move_menu_cb")
 
@@ -341,23 +341,6 @@ ephy_tab_move_menu_finalize (GObject *object)
 {
 	EphyTabMoveMenu *menu = EPHY_TAB_MOVE_MENU (object); 
 
-	GtkActionGroup *action_group;
-	GtkAction *action;
-
-/*
-	action_group = find_action_group (menu->priv->manager);
-	g_return_if_fail (action_group != NULL);
-
-	action = gtk_action_group_get_action (action_group, "TabMoveTo");
-	g_return_if_fail (action != NULL);
-
-	gtk_action_group_remove_action (action_group, action);
-
-	action = gtk_ui_manager_get_action (menu->priv->manager, "/menubar/TabsMenu");
-	g_return_if_fail (action != NULL);
-
-	g_signal_handlers_disconnect_by_func (action, G_CALLBACK (update_tab_move_menu_cb), menu);
-*/
 	if (menu->priv->merge_id != 0)
 	{
 		gtk_ui_manager_remove_ui (menu->priv->manager,
